@@ -2,15 +2,14 @@ package Fl;
 use 5.008001;
 use strict;
 use warnings;
-our $VERSION = '0.99.00';
+our $VERSION = '0.99.1';
 use XSLoader;
 use vars qw[@EXPORT_OK @EXPORT %EXPORT_TAGS];
 use Exporter qw[import];
 #
 our $NOXS ||= $0 eq __FILE__;    # for testing
 XSLoader::load 'Fl', $VERSION
-    if !$Fl::NOXS
-    ;                            # Fills %EXPORT_TAGS on BOOT
+    if !$Fl::NOXS;               # Fills %EXPORT_TAGS on BOOT
 #
 @EXPORT_OK = sort map { @$_ = sort @$_; @$_ } values %EXPORT_TAGS;
 $EXPORT_TAGS{'all'} = \@EXPORT_OK;    # When you want to import everything
@@ -18,13 +17,18 @@ $EXPORT_TAGS{'all'} = \@EXPORT_OK;    # When you want to import everything
     = sort map { defined $EXPORT_TAGS{$_} ? @{$EXPORT_TAGS{$_}} : () }
     qw[box font label]
     if 1 < scalar keys %EXPORT_TAGS;
+@{$EXPORT_TAGS{'enum'}}               # Merge these under a single tag
+    = sort map { defined $EXPORT_TAGS{$_} ? @{$EXPORT_TAGS{$_}} : () }
+    qw[box font label version]
+    if 1 < scalar keys %EXPORT_TAGS;
 @EXPORT    # Export these tags (if prepended w/ ':') or functions by default
     = sort map { m[^:(.+)] ? @{$EXPORT_TAGS{$1}} : $_ } qw[:style :default]
     if 0 && keys %EXPORT_TAGS > 1;
-
 1;
 __END__
 
+=pod
+
 =encoding utf-8
 
 =head1 NAME
@@ -33,12 +37,12 @@ Fl - Bindings for the Stable 1.3.x Branch of the Fast Light Toolkit
 
 =head1 SYNOPSIS
 
-    use Fl qw[:execute];
+    use Fl qw[:execute :label :box :font];
     my $window = Fl::Window->new(100, 100, 300, 180);
-    my $box = Fl::Box->new(20, 40, 260, 100, 'Hello, World');
-    #$box->labelfont(BOLD + ITALIC); # TODO
+    my $box = Fl::Box->new(FL_UP_BOX, 20, 40, 260, 100, 'Hello, World');
+    $box->labelfont(FL_BOLD + FL_ITALIC);
     $box->labelsize(36);
-    #$box->labelfont(SHADOW_LABEL); # TODO
+    $box->labeltype(FL_SHADOW_LABEL);
     $window->end();
     $window->show();
     exit run();
@@ -50,9 +54,12 @@ Light Toolkit; a cross-platform GUI toolkit compatible with Microsoft Windows,
 MacOS X, and Linux/Unix platforms with X11. It was designed to be small, quick
 and comes with a very simple yet complete API.
 
-=head1 Functions
+=head1 Functions & Exports
 
-The top level Fl namespace exports several functions sorted by type.
+The top level Fl namespace exports several functions sorted by type. This list
+will grow as the dist develops.
+
+=head2 C<:execute>
 
     use Fl qw[:execute];
 
@@ -111,7 +118,13 @@ return true until you call C<Fl::check()> or C<Fl::wait()>).
 
 =back
 
-This list will grow.
+=head2 C<:enum>
+
+    use Fl qw[:enum]; # All Fl::Enumeration values
+    use Fl qw[:font]; # Only import enum values related to fonttype
+
+The C<:enum> and related tags allow you to import values listed in
+Fl::Enumerations.
 
 =head1 Classes
 
@@ -121,6 +134,8 @@ Fl contains several widgets and other classes including:
 
 =item L<Fl::Box>
 
+=item L<Fl::Group>
+
 =item L<Fl::Window>
 
 =back
@@ -139,4 +154,3 @@ it under the same terms as Perl itself.
 Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 =cut
-
